"""droplo - Official Python SDK for the droplo.io content API"""

__title__ = 'droplo'
__version__ = '0.1.1'
__author__ = 'Droplo Inc <contact@droplo.io>'
__license__ = 'MIT'

from .api import Api  # noqa: F401
